mapping = {
    "default": {
        "core_allocation": [0, 1, 2, 3],
    },
    "Conv": {
        "core_allocation": [0, 1, 2, 3],
    },
    "Gemm": {
        "core_allocation": [0, 1, 2, 3],
    },
    "Pool": {
        "core_allocation": 4,
    },
    "MaxPool": {
        "core_allocation": 4,
    },
    "AveragePool": {
        "core_allocation": 4,
    },
    "GlobalAveragePool": {
        "core_allocation": 4,
    },
    "Add": {
        "core_allocation": 5,
    },
}